@@ -6,7 +6,7 @@
 #' @param snp  an rsID or chromosome coordinate (e.g. "chr7:24966446"), one per query
 #' @param pop a 1000 Genomes Project population, (e.g. YRI or CEU), multiple allowed, default = "CEU"
 #' @param r2d either "r2" for LD R2 or "d" for LD D', default = "r2"
-#' @param token LDlink provided user token, default = NULL, register for token at  \url{https://ldlink.nci.nih.gov/?tab=apiaccess}
+#' @param token LDlink provided user token, default = NULL, register for token at  \url{https://ldlink.nih.gov/?tab=apiaccess}
 #' @param file Optional character string naming a path and file for saving results.  If file = FALSE, no file will be generated, default = FALSE.
 #' @param genome_build Choose between one of the three options...`grch37` for genome build GRCh37 (hg19),
 #' `grch38` for GRCh38 (hg38), or `grch38_high_coverage` for GRCh38 High Coverage (hg38) 1000 Genome Project
@@ -27,7 +27,7 @@ LDproxy <- function(snp,
                     token=NULL,
                     file = FALSE,
                     genome_build = "grch37",
-                    api_root="https://ldlink.nci.nih.gov/LDlinkRest") {
+                    api_root="https://ldlink.nih.gov/LDlinkRest") {
 
   LD_config <- list(ldproxy.url=paste0(api_root,"/ldproxy"),
                     avail_pop=c("YRI","LWK","GWD","MSL","ESN","ASW","ACB",
@@ -82,7 +82,7 @@ file <- as.character(file)
   }
 
   if(is.null(token)) {
-    stop("Enter valid access token. Please register using the LDlink API Access tab: https://ldlink.nci.nih.gov/?tab=apiaccess")
+    stop("Enter valid access token. Please register using the LDlink API Access tab: https://ldlink.nih.gov/?tab=apiaccess")
   }
 
  # Ensure input for 'genome_build' is valid.
